class C<T__2, U__2> {
    constructor(public t__3: T__2, public u__3: U__2){}
    foo(t__4: T__2, u__4: U__2) {
        return t__4;
    }
    foo2(t__5: T__2, u__5: U__2) {
        return u__5;
    }
    foo3<T__6>(t__6: T__6, u__6: U__2) {
        return t__6;
    }
    foo4<U__7>(t__7: T__2, u__7: U__7) {
        return t__7;
    }
    foo5<T__8, U__8>(t__8: T__8, u__8: U__8) {
        return t__8;
    }
    foo6<T__9, U__9>() {
        var x__9: T__9;
        return x__9;
    }
    foo7<T__10, U__10>(u__10: U__10) {
        var x__10: T__10;
        return x__10;
    }
    foo8<T__11, U__11>() {
        var x__11: T__11;
        return x__11;
    }
}
